Class: Aws::CostOptimizationHub::Types::EbsVolumeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costoptimizationhub/types.rb

Overview

The Amazon Elastic Block Store volume configuration used for recommendations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_stateString

The Amazon Elastic Block Store attachment state.

Returns:

  • (String)


214
215
216
217
218
219
220
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 214

class EbsVolumeConfiguration < Struct.new(
  :storage,
  :performance,
  :attachment_state)
  SENSITIVE = []
  include Aws::Structure
end

#performanceTypes::BlockStoragePerformanceConfiguration

The Amazon Elastic Block Store performance configuration.



214
215
216
217
218
219
220
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 214

class EbsVolumeConfiguration < Struct.new(
  :storage,
  :performance,
  :attachment_state)
  SENSITIVE = []
  include Aws::Structure
end

#storageTypes::StorageConfiguration

The disk storage of the Amazon Elastic Block Store volume.



214
215
216
217
218
219
220
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 214

class EbsVolumeConfiguration < Struct.new(
  :storage,
  :performance,
  :attachment_state)
  SENSITIVE = []
  include Aws::Structure
end