Class: Aws::CostOptimizationHub::Types::Ec2ReservedInstancesConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costoptimizationhub/types.rb

Overview

The EC2 reserved instances configuration used for recommendations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_scopeString

The account scope for which you want recommendations.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#current_generationString

Determines whether the recommendation is for a current generation instance.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#instance_familyString

The instance family of the recommended reservation.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of instance that Amazon Web Services recommends.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_recurring_costString

How much purchasing these reserved instances costs you on a monthly basis.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#normalized_units_to_purchaseString

The number of normalized units that Amazon Web Services recommends that you purchase.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_instances_to_purchaseString

The number of instances that Amazon Web Services recommends that you purchase.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#offering_classString

Indicates whether the recommendation is for standard or convertible reservations.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#payment_optionString

The payment option for the commitment.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The platform of the recommended reservation. The platform is the specific combination of operating system, license model, and software on an instance.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_instances_regionString

The Amazon Web Services Region of the commitment.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The service for which you want recommendations.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#size_flex_eligibleBoolean

Determines whether the recommendation is size flexible.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#tenancyString

Determines whether the recommended reservation is dedicated or shared.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#termString

The reserved instances recommendation term in years.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#upfront_costString

How much purchasing this instance costs you upfront.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 572

class Ec2ReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :offering_class,
  :instance_family,
  :instance_type,
  :current_generation,
  :platform,
  :tenancy,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end