Class: Aws::CostOptimizationHub::Types::EfficiencyMetricsByGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostOptimizationHub::Types::EfficiencyMetricsByGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costoptimizationhub/types.rb
Overview
Contains cost efficiency metrics for a specific group over time. The group is defined by the grouping dimension specified in the request, such as account ID, Amazon Web Services Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group ⇒ String
The value of the grouping dimension for this set of metrics.
-
#message ⇒ String
An explanation of why efficiency metrics could not be calculated for this group when the metricsByTime field is null.
-
#metrics_by_time ⇒ Array<Types::MetricsByTime>
A list of time-series data points containing efficiency metrics for this group.
Instance Attribute Details
#group ⇒ String
The value of the grouping dimension for this set of metrics. For example, if grouped by account ID, this field contains the account ID. If no grouping is specified, this field is empty.
683 684 685 686 687 688 689 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 683 class EfficiencyMetricsByGroup < Struct.new( :metrics_by_time, :group, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
An explanation of why efficiency metrics could not be calculated for this group when the metricsByTime field is null. Common reasons include insufficient or inconclusive cost and usage data during the specified time period. This field is null or empty when metrics are successfully calculated.
683 684 685 686 687 688 689 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 683 class EfficiencyMetricsByGroup < Struct.new( :metrics_by_time, :group, :message) SENSITIVE = [] include Aws::Structure end |
#metrics_by_time ⇒ Array<Types::MetricsByTime>
A list of time-series data points containing efficiency metrics for this group. Each data point includes an efficiency score, estimated savings, spending, and a timestamp corresponding to the specified granularity. This field is null when efficiency metrics cannot be calculated for the group, in which case the message field provides an explanation.
683 684 685 686 687 688 689 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 683 class EfficiencyMetricsByGroup < Struct.new( :metrics_by_time, :group, :message) SENSITIVE = [] include Aws::Structure end |