Class: Aws::CostOptimizationHub::Types::ElastiCacheReservedInstancesConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostOptimizationHub::Types::ElastiCacheReservedInstancesConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costoptimizationhub/types.rb
Overview
The ElastiCache reserved instances configuration used for recommendations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_scope ⇒ String
The account scope for which you want recommendations.
-
#current_generation ⇒ String
Determines whether the recommendation is for a current generation instance.
-
#instance_family ⇒ String
The instance family of the recommended reservation.
-
#instance_type ⇒ String
The type of instance that Amazon Web Services recommends.
-
#monthly_recurring_cost ⇒ String
How much purchasing these reserved instances costs you on a monthly basis.
-
#normalized_units_to_purchase ⇒ String
The number of normalized units that Amazon Web Services recommends that you purchase.
-
#number_of_instances_to_purchase ⇒ String
The number of instances that Amazon Web Services recommends that you purchase.
-
#payment_option ⇒ String
The payment option for the commitment.
-
#reserved_instances_region ⇒ String
The Amazon Web Services Region of the commitment.
-
#service ⇒ String
The service for which you want recommendations.
-
#size_flex_eligible ⇒ Boolean
Determines whether the recommendation is size flexible.
-
#term ⇒ String
The reserved instances recommendation term in years.
-
#upfront_cost ⇒ String
How much purchasing this instance costs you upfront.
Instance Attribute Details
#account_scope ⇒ String
The account scope for which you want recommendations.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#current_generation ⇒ String
Determines whether the recommendation is for a current generation instance.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#instance_family ⇒ String
The instance family of the recommended reservation.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of instance that Amazon Web Services recommends.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#monthly_recurring_cost ⇒ String
How much purchasing these reserved instances costs you on a monthly basis.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#normalized_units_to_purchase ⇒ String
The number of normalized units that Amazon Web Services recommends that you purchase.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#number_of_instances_to_purchase ⇒ String
The number of instances that Amazon Web Services recommends that you purchase.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option for the commitment.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_region ⇒ String
The Amazon Web Services Region of the commitment.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The service for which you want recommendations.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#size_flex_eligible ⇒ Boolean
Determines whether the recommendation is size flexible.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#term ⇒ String
The reserved instances recommendation term in years.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#upfront_cost ⇒ String
How much purchasing this instance costs you upfront.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 786 class ElastiCacheReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |