Class: Aws::CostOptimizationHub::Types::GetRecommendationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costoptimizationhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The account to which the recommendation applies.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#action_typeString

The type of action you can take by adopting the recommendation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#cost_calculation_lookback_period_in_daysInteger

The lookback period used to calculate cost impact for a recommendation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#currency_codeString

The currency code used for the recommendation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#current_resource_detailsTypes::ResourceDetails

The details for the resource.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#current_resource_typeString

The type of resource.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_monthly_costFloat

The estimated monthly cost of the current resource. For Reserved Instances and Savings Plans, it refers to the cost for eligible usage.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_monthly_savingsFloat

The estimated monthly savings amount for the recommendation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_savings_over_cost_calculation_lookback_periodFloat

The estimated savings amount over the lookback period used to calculate cost impact for a recommendation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_savings_percentageFloat

The estimated savings percentage relative to the total cost over the cost calculation lookback period.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#implementation_effortString

The effort required to implement the recommendation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_refresh_timestampTime

The time when the recommendation was last generated.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_idString

The ID for the recommendation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_lookback_period_in_daysInteger

The lookback period that’s used to generate the recommendation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

The details about the recommended resource.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

The resource type of the recommendation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region of the resource.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the resource.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The unique identifier for the resource. This is the same as the Amazon Resource Name (ARN), if available.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#restart_neededBoolean

Whether or not implementing the recommendation requires a restart.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rollback_possibleBoolean

Whether or not implementing the recommendation can be rolled back.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The source of the recommendation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags associated with the resource for which the recommendation exists.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 998

class GetRecommendationResponse < Struct.new(
  :recommendation_id,
  :resource_id,
  :resource_arn,
  :account_id,
  :currency_code,
  :recommendation_lookback_period_in_days,
  :cost_calculation_lookback_period_in_days,
  :estimated_savings_percentage,
  :estimated_savings_over_cost_calculation_lookback_period,
  :current_resource_type,
  :recommended_resource_type,
  :region,
  :source,
  :last_refresh_timestamp,
  :estimated_monthly_savings,
  :estimated_monthly_cost,
  :implementation_effort,
  :restart_needed,
  :action_type,
  :rollback_possible,
  :current_resource_details,
  :recommended_resource_details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end