Class: Aws::CostOptimizationHub::Types::MemoryDbReservedInstancesConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costoptimizationhub/types.rb

Overview

The MemoryDB reserved instances configuration used for recommendations.

While the API reference uses "MemoryDB reserved instances", the user guide and other documentation refer to them as "MemoryDB reserved nodes", as the terms are used interchangeably.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_scopeString

The account scope for which you want recommendations.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#current_generationString

Determines whether the recommendation is for a current generation instance.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#instance_familyString

The instance family of the recommended reservation.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of instance that Amazon Web Services recommends.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_recurring_costString

How much purchasing these reserved instances costs you on a monthly basis.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#normalized_units_to_purchaseString

The number of normalized units that Amazon Web Services recommends that you purchase.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_instances_to_purchaseString

The number of instances that Amazon Web Services recommends that you purchase.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#payment_optionString

The payment option for the commitment.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_instances_regionString

The Amazon Web Services Region of the commitment.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The service for which you want recommendations.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#size_flex_eligibleBoolean

Determines whether the recommendation is size flexible.

Returns:

  • (Boolean)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#termString

The reserved instances recommendation term in years.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end

#upfront_costString

How much purchasing these reserved instances costs you upfront.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486

class MemoryDbReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_type,
  :instance_family,
  :size_flex_eligible,
  :current_generation)
  SENSITIVE = []
  include Aws::Structure
end