Class: Aws::CostOptimizationHub::Types::RdsReservedInstancesConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costoptimizationhub/types.rb

Overview

The RDS reserved instances configuration used for recommendations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_scopeString

The account scope for which you want recommendations.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#current_generationString

Determines whether the recommendation is for a current generation instance.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#database_editionString

The database edition that the recommended reservation supports.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#database_engineString

The database engine that the recommended reservation supports.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_optionString

Determines whether the recommendation is for a reservation in a single Availability Zone or a reservation with a backup in a second Availability Zone.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#instance_familyString

The instance family of the recommended reservation.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of instance that Amazon Web Services recommends.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#license_modelString

The license model that the recommended reservation supports.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_recurring_costString

How much purchasing this instance costs you on a monthly basis.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#normalized_units_to_purchaseString

The number of normalized units that Amazon Web Services recommends that you purchase.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_instances_to_purchaseString

The number of instances that Amazon Web Services recommends that you purchase.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#payment_optionString

The payment option for the commitment.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_instances_regionString

The Amazon Web Services Region of the commitment.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The service for which you want recommendations.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#size_flex_eligibleBoolean

Determines whether the recommendation is size flexible.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#termString

The reserved instances recommendation term in years.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#upfront_costString

How much purchasing this instance costs you upfront.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1861

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end