Class: Aws::CostOptimizationHub::Types::Recommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostOptimizationHub::Types::Recommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costoptimizationhub/types.rb
Overview
Describes a recommendation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account to which the recommendation applies.
-
#action_type ⇒ String
The type of tasks that can be carried out by this action.
-
#currency_code ⇒ String
The currency code used for the recommendation.
-
#current_resource_summary ⇒ String
Describes the current resource.
-
#current_resource_type ⇒ String
The current resource type.
-
#estimated_monthly_cost ⇒ Float
The estimated monthly cost of the current resource.
-
#estimated_monthly_savings ⇒ Float
The estimated monthly savings amount for the recommendation.
-
#estimated_savings_percentage ⇒ Float
The estimated savings percentage relative to the total cost over the cost calculation lookback period.
-
#implementation_effort ⇒ String
The effort required to implement the recommendation.
-
#last_refresh_timestamp ⇒ Time
The time when the recommendation was last generated.
-
#recommendation_id ⇒ String
The ID for the recommendation.
-
#recommendation_lookback_period_in_days ⇒ Integer
The lookback period that’s used to generate the recommendation.
-
#recommended_resource_summary ⇒ String
Describes the recommended resource.
-
#recommended_resource_type ⇒ String
The recommended resource type.
-
#region ⇒ String
The Amazon Web Services Region of the resource.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the recommendation.
-
#resource_id ⇒ String
The resource ID for the recommendation.
-
#restart_needed ⇒ Boolean
Whether or not implementing the recommendation requires a restart.
-
#rollback_possible ⇒ Boolean
Whether or not implementing the recommendation can be rolled back.
-
#source ⇒ String
The source of the recommendation.
-
#tags ⇒ Array<Types::Tag>
A list of tags assigned to the recommendation.
Instance Attribute Details
#account_id ⇒ String
The account to which the recommendation applies.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#action_type ⇒ String
The type of tasks that can be carried out by this action.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency code used for the recommendation.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#current_resource_summary ⇒ String
Describes the current resource.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#current_resource_type ⇒ String
The current resource type.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#estimated_monthly_cost ⇒ Float
The estimated monthly cost of the current resource. For Reserved Instances and Savings Plans, it refers to the cost for eligible usage.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#estimated_monthly_savings ⇒ Float
The estimated monthly savings amount for the recommendation.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#estimated_savings_percentage ⇒ Float
The estimated savings percentage relative to the total cost over the cost calculation lookback period.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#implementation_effort ⇒ String
The effort required to implement the recommendation.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#last_refresh_timestamp ⇒ Time
The time when the recommendation was last generated.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#recommendation_id ⇒ String
The ID for the recommendation.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#recommendation_lookback_period_in_days ⇒ Integer
The lookback period that’s used to generate the recommendation.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#recommended_resource_summary ⇒ String
Describes the recommended resource.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#recommended_resource_type ⇒ String
The recommended resource type.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region of the resource.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the recommendation.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The resource ID for the recommendation.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#restart_needed ⇒ Boolean
Whether or not implementing the recommendation requires a restart.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#rollback_possible ⇒ Boolean
Whether or not implementing the recommendation can be rolled back.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source of the recommendation.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags assigned to the recommendation.
2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2030 class Recommendation < Struct.new( :recommendation_id, :account_id, :region, :resource_id, :resource_arn, :current_resource_type, :recommended_resource_type, :estimated_monthly_savings, :estimated_savings_percentage, :estimated_monthly_cost, :currency_code, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_summary, :recommended_resource_summary, :last_refresh_timestamp, :recommendation_lookback_period_in_days, :source, :tags) SENSITIVE = [] include Aws::Structure end |