Class: Aws::CostOptimizationHub::Types::RecommendationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostOptimizationHub::Types::RecommendationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costoptimizationhub/types.rb
Overview
The summary of rightsizing recommendations, including de-duped savings from all types of recommendations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#estimated_monthly_savings ⇒ Float
The estimated total savings resulting from modifications, on a monthly basis.
-
#group ⇒ String
The grouping of recommendations.
-
#recommendation_count ⇒ Integer
The total number of instance recommendations.
Instance Attribute Details
#estimated_monthly_savings ⇒ Float
The estimated total savings resulting from modifications, on a monthly basis.
2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2074 class RecommendationSummary < Struct.new( :group, :estimated_monthly_savings, :recommendation_count) SENSITIVE = [] include Aws::Structure end |
#group ⇒ String
The grouping of recommendations.
2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2074 class RecommendationSummary < Struct.new( :group, :estimated_monthly_savings, :recommendation_count) SENSITIVE = [] include Aws::Structure end |
#recommendation_count ⇒ Integer
The total number of instance recommendations.
2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2074 class RecommendationSummary < Struct.new( :group, :estimated_monthly_savings, :recommendation_count) SENSITIVE = [] include Aws::Structure end |