Class: Aws::CostOptimizationHub::Types::RedshiftReservedInstancesConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostOptimizationHub::Types::RedshiftReservedInstancesConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costoptimizationhub/types.rb
Overview
The Redshift reserved instances configuration used for recommendations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_scope ⇒ String
The account scope for which you want recommendations.
-
#current_generation ⇒ String
Determines whether the recommendation is for a current generation instance.
-
#instance_family ⇒ String
The instance family of the recommended reservation.
-
#instance_type ⇒ String
The type of instance that Amazon Web Services recommends.
-
#monthly_recurring_cost ⇒ String
How much purchasing these reserved instances costs you on a monthly basis.
-
#normalized_units_to_purchase ⇒ String
The number of normalized units that Amazon Web Services recommends that you purchase.
-
#number_of_instances_to_purchase ⇒ String
The number of instances that Amazon Web Services recommends that you purchase.
-
#payment_option ⇒ String
The payment option for the commitment.
-
#reserved_instances_region ⇒ String
The Amazon Web Services Region of the commitment.
-
#service ⇒ String
The service for which you want recommendations.
-
#size_flex_eligible ⇒ Boolean
Determines whether the recommendation is size flexible.
-
#term ⇒ String
The reserved instances recommendation term in years.
-
#upfront_cost ⇒ String
How much purchasing this instance costs you upfront.
Instance Attribute Details
#account_scope ⇒ String
The account scope for which you want recommendations.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#current_generation ⇒ String
Determines whether the recommendation is for a current generation instance.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#instance_family ⇒ String
The instance family of the recommended reservation.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of instance that Amazon Web Services recommends.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#monthly_recurring_cost ⇒ String
How much purchasing these reserved instances costs you on a monthly basis.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#normalized_units_to_purchase ⇒ String
The number of normalized units that Amazon Web Services recommends that you purchase.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#number_of_instances_to_purchase ⇒ String
The number of instances that Amazon Web Services recommends that you purchase.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option for the commitment.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_region ⇒ String
The Amazon Web Services Region of the commitment.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The service for which you want recommendations.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#size_flex_eligible ⇒ Boolean
Determines whether the recommendation is size flexible.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#term ⇒ String
The reserved instances recommendation term in years.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#upfront_cost ⇒ String
How much purchasing this instance costs you upfront.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 2163 class RedshiftReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_family, :instance_type, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |