Class: Aws::CostOptimizationHub::Types::EbsVolumeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostOptimizationHub::Types::EbsVolumeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costoptimizationhub/types.rb
Overview
The Amazon Elastic Block Store volume configuration used for recommendations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_state ⇒ String
The Amazon Elastic Block Store attachment state.
-
#performance ⇒ Types::BlockStoragePerformanceConfiguration
The Amazon Elastic Block Store performance configuration.
-
#storage ⇒ Types::StorageConfiguration
The disk storage of the Amazon Elastic Block Store volume.
Instance Attribute Details
#attachment_state ⇒ String
The Amazon Elastic Block Store attachment state.
214 215 216 217 218 219 220 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 214 class EbsVolumeConfiguration < Struct.new( :storage, :performance, :attachment_state) SENSITIVE = [] include Aws::Structure end |
#performance ⇒ Types::BlockStoragePerformanceConfiguration
The Amazon Elastic Block Store performance configuration.
214 215 216 217 218 219 220 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 214 class EbsVolumeConfiguration < Struct.new( :storage, :performance, :attachment_state) SENSITIVE = [] include Aws::Structure end |
#storage ⇒ Types::StorageConfiguration
The disk storage of the Amazon Elastic Block Store volume.
214 215 216 217 218 219 220 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 214 class EbsVolumeConfiguration < Struct.new( :storage, :performance, :attachment_state) SENSITIVE = [] include Aws::Structure end |