Class: Aws::CostOptimizationHub::Types::Ec2ReservedInstancesConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostOptimizationHub::Types::Ec2ReservedInstancesConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costoptimizationhub/types.rb
Overview
The EC2 reserved instances configuration used for recommendations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_scope ⇒ String
The account scope for which you want recommendations.
-
#current_generation ⇒ String
Determines whether the recommendation is for a current generation instance.
-
#instance_family ⇒ String
The instance family of the recommended reservation.
-
#instance_type ⇒ String
The type of instance that Amazon Web Services recommends.
-
#monthly_recurring_cost ⇒ String
How much purchasing these reserved instances costs you on a monthly basis.
-
#normalized_units_to_purchase ⇒ String
The number of normalized units that Amazon Web Services recommends that you purchase.
-
#number_of_instances_to_purchase ⇒ String
The number of instances that Amazon Web Services recommends that you purchase.
-
#offering_class ⇒ String
Indicates whether the recommendation is for standard or convertible reservations.
-
#payment_option ⇒ String
The payment option for the commitment.
-
#platform ⇒ String
The platform of the recommended reservation.
-
#reserved_instances_region ⇒ String
The Amazon Web Services Region of the commitment.
-
#service ⇒ String
The service for which you want recommendations.
-
#size_flex_eligible ⇒ Boolean
Determines whether the recommendation is size flexible.
-
#tenancy ⇒ String
Determines whether the recommended reservation is dedicated or shared.
-
#term ⇒ String
The reserved instances recommendation term in years.
-
#upfront_cost ⇒ String
How much purchasing this instance costs you upfront.
Instance Attribute Details
#account_scope ⇒ String
The account scope for which you want recommendations.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#current_generation ⇒ String
Determines whether the recommendation is for a current generation instance.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#instance_family ⇒ String
The instance family of the recommended reservation.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of instance that Amazon Web Services recommends.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#monthly_recurring_cost ⇒ String
How much purchasing these reserved instances costs you on a monthly basis.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#normalized_units_to_purchase ⇒ String
The number of normalized units that Amazon Web Services recommends that you purchase.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#number_of_instances_to_purchase ⇒ String
The number of instances that Amazon Web Services recommends that you purchase.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#offering_class ⇒ String
Indicates whether the recommendation is for standard or convertible reservations.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option for the commitment.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The platform of the recommended reservation. The platform is the specific combination of operating system, license model, and software on an instance.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_region ⇒ String
The Amazon Web Services Region of the commitment.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The service for which you want recommendations.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#size_flex_eligible ⇒ Boolean
Determines whether the recommendation is size flexible.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#tenancy ⇒ String
Determines whether the recommended reservation is dedicated or shared.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#term ⇒ String
The reserved instances recommendation term in years.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#upfront_cost ⇒ String
How much purchasing this instance costs you upfront.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 600 class Ec2ReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :offering_class, :instance_family, :instance_type, :current_generation, :platform, :tenancy, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |