Class: Aws::CostOptimizationHub::Types::GetRecommendationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostOptimizationHub::Types::GetRecommendationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costoptimizationhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account to which the recommendation applies.
-
#action_type ⇒ String
The type of action you can take by adopting the recommendation.
-
#cost_calculation_lookback_period_in_days ⇒ Integer
The lookback period used to calculate cost impact for a recommendation.
-
#currency_code ⇒ String
The currency code used for the recommendation.
-
#current_resource_details ⇒ Types::ResourceDetails
The details for the resource.
-
#current_resource_type ⇒ String
The type of resource.
-
#estimated_monthly_cost ⇒ Float
The estimated monthly cost of the current resource.
-
#estimated_monthly_savings ⇒ Float
The estimated monthly savings amount for the recommendation.
-
#estimated_savings_over_cost_calculation_lookback_period ⇒ Float
The estimated savings amount over the lookback period used to calculate cost impact for a recommendation.
-
#estimated_savings_percentage ⇒ Float
The estimated savings percentage relative to the total cost over the cost calculation lookback period.
-
#implementation_effort ⇒ String
The effort required to implement the recommendation.
-
#last_refresh_timestamp ⇒ Time
The time when the recommendation was last generated.
-
#recommendation_id ⇒ String
The ID for the recommendation.
-
#recommendation_lookback_period_in_days ⇒ Integer
The lookback period that’s used to generate the recommendation.
-
#recommended_resource_details ⇒ Types::ResourceDetails
The details about the recommended resource.
-
#recommended_resource_type ⇒ String
The resource type of the recommendation.
-
#region ⇒ String
The Amazon Web Services Region of the resource.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource.
-
#resource_id ⇒ String
The unique identifier for the resource.
-
#restart_needed ⇒ Boolean
Whether or not implementing the recommendation requires a restart.
-
#rollback_possible ⇒ Boolean
Whether or not implementing the recommendation can be rolled back.
-
#source ⇒ String
The source of the recommendation.
-
#tags ⇒ Array<Types::Tag>
A list of tags associated with the resource for which the recommendation exists.
Instance Attribute Details
#account_id ⇒ String
The account to which the recommendation applies.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#action_type ⇒ String
The type of action you can take by adopting the recommendation.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#cost_calculation_lookback_period_in_days ⇒ Integer
The lookback period used to calculate cost impact for a recommendation.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency code used for the recommendation.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#current_resource_details ⇒ Types::ResourceDetails
The details for the resource.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#current_resource_type ⇒ String
The type of resource.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#estimated_monthly_cost ⇒ Float
The estimated monthly cost of the current resource. For Reserved Instances and Savings Plans, it refers to the cost for eligible usage.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#estimated_monthly_savings ⇒ Float
The estimated monthly savings amount for the recommendation.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#estimated_savings_over_cost_calculation_lookback_period ⇒ Float
The estimated savings amount over the lookback period used to calculate cost impact for a recommendation.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#estimated_savings_percentage ⇒ Float
The estimated savings percentage relative to the total cost over the cost calculation lookback period.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#implementation_effort ⇒ String
The effort required to implement the recommendation.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#last_refresh_timestamp ⇒ Time
The time when the recommendation was last generated.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#recommendation_id ⇒ String
The ID for the recommendation.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#recommendation_lookback_period_in_days ⇒ Integer
The lookback period that’s used to generate the recommendation.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#recommended_resource_details ⇒ Types::ResourceDetails
The details about the recommended resource.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#recommended_resource_type ⇒ String
The resource type of the recommendation.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region of the resource.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The unique identifier for the resource. This is the same as the Amazon Resource Name (ARN), if available.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#restart_needed ⇒ Boolean
Whether or not implementing the recommendation requires a restart.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#rollback_possible ⇒ Boolean
Whether or not implementing the recommendation can be rolled back.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source of the recommendation.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags associated with the resource for which the recommendation exists.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1040 class GetRecommendationResponse < Struct.new( :recommendation_id, :resource_id, :resource_arn, :account_id, :currency_code, :recommendation_lookback_period_in_days, :cost_calculation_lookback_period_in_days, :estimated_savings_percentage, :estimated_savings_over_cost_calculation_lookback_period, :current_resource_type, :recommended_resource_type, :region, :source, :last_refresh_timestamp, :estimated_monthly_savings, :estimated_monthly_cost, :implementation_effort, :restart_needed, :action_type, :rollback_possible, :current_resource_details, :recommended_resource_details, :tags) SENSITIVE = [] include Aws::Structure end |