Class: Aws::CostOptimizationHub::Types::MemoryDbReservedInstancesConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostOptimizationHub::Types::MemoryDbReservedInstancesConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costoptimizationhub/types.rb
Overview
The MemoryDB reserved instances configuration used for recommendations.
<note markdown=“1”> While the API reference uses “MemoryDB reserved instances”, the user guide and other documentation refer to them as “MemoryDB reserved nodes”, as the terms are used interchangeably.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_scope ⇒ String
The account scope for which you want recommendations.
-
#current_generation ⇒ String
Determines whether the recommendation is for a current generation instance.
-
#instance_family ⇒ String
The instance family of the recommended reservation.
-
#instance_type ⇒ String
The type of instance that Amazon Web Services recommends.
-
#monthly_recurring_cost ⇒ String
How much purchasing these reserved instances costs you on a monthly basis.
-
#normalized_units_to_purchase ⇒ String
The number of normalized units that Amazon Web Services recommends that you purchase.
-
#number_of_instances_to_purchase ⇒ String
The number of instances that Amazon Web Services recommends that you purchase.
-
#payment_option ⇒ String
The payment option for the commitment.
-
#reserved_instances_region ⇒ String
The Amazon Web Services Region of the commitment.
-
#service ⇒ String
The service for which you want recommendations.
-
#size_flex_eligible ⇒ Boolean
Determines whether the recommendation is size flexible.
-
#term ⇒ String
The reserved instances recommendation term in years.
-
#upfront_cost ⇒ String
How much purchasing these reserved instances costs you upfront.
Instance Attribute Details
#account_scope ⇒ String
The account scope for which you want recommendations.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#current_generation ⇒ String
Determines whether the recommendation is for a current generation instance.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#instance_family ⇒ String
The instance family of the recommended reservation.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of instance that Amazon Web Services recommends.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#monthly_recurring_cost ⇒ String
How much purchasing these reserved instances costs you on a monthly basis.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#normalized_units_to_purchase ⇒ String
The number of normalized units that Amazon Web Services recommends that you purchase.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#number_of_instances_to_purchase ⇒ String
The number of instances that Amazon Web Services recommends that you purchase.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option for the commitment.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_region ⇒ String
The Amazon Web Services Region of the commitment.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The service for which you want recommendations.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#size_flex_eligible ⇒ Boolean
Determines whether the recommendation is size flexible.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#term ⇒ String
The reserved instances recommendation term in years.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |
#upfront_cost ⇒ String
How much purchasing these reserved instances costs you upfront.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1486 class MemoryDbReservedInstancesConfiguration < Struct.new( :account_scope, :service, :term, :payment_option, :reserved_instances_region, :upfront_cost, :monthly_recurring_cost, :normalized_units_to_purchase, :number_of_instances_to_purchase, :instance_type, :instance_family, :size_flex_eligible, :current_generation) SENSITIVE = [] include Aws::Structure end |