Class: Aws::CostOptimizationHub::Types::RdsReservedInstancesConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costoptimizationhub/types.rb

Overview

The RDS reserved instances configuration used for recommendations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_scopeString

The account scope for which you want recommendations.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#current_generationString

Determines whether the recommendation is for a current generation instance.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#database_editionString

The database edition that the recommended reservation supports.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#database_engineString

The database engine that the recommended reservation supports.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_optionString

Determines whether the recommendation is for a reservation in a single Availability Zone or a reservation with a backup in a second Availability Zone.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#instance_familyString

The instance family of the recommended reservation.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of instance that Amazon Web Services recommends.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#license_modelString

The license model that the recommended reservation supports.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_recurring_costString

How much purchasing this instance costs you on a monthly basis.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#normalized_units_to_purchaseString

The number of normalized units that Amazon Web Services recommends that you purchase.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_instances_to_purchaseString

The number of instances that Amazon Web Services recommends that you purchase.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#payment_optionString

The payment option for the commitment.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_instances_regionString

The Amazon Web Services Region of the commitment.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The service for which you want recommendations.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#size_flex_eligibleBoolean

Determines whether the recommendation is size flexible.

Returns:

  • (Boolean)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#termString

The reserved instances recommendation term in years.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end

#upfront_costString

How much purchasing this instance costs you upfront.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1917

class RdsReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :term,
  :payment_option,
  :reserved_instances_region,
  :upfront_cost,
  :monthly_recurring_cost,
  :normalized_units_to_purchase,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :size_flex_eligible,
  :current_generation,
  :license_model,
  :database_edition,
  :database_engine,
  :deployment_option)
  SENSITIVE = []
  include Aws::Structure
end