Class: Aws::CostOptimizationHub::Types::RedshiftReservedInstancesConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costoptimizationhub/types.rb

Overview

The Redshift reserved instances configuration used for recommendations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_scopeString

The account scope that you want your recommendations for.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#current_generationString

Determines whether the recommendation is for a current generation instance.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#instance_familyString

The instance family of the recommended reservation.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of instance that Amazon Web Services recommends.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_recurring_costString

How much purchasing reserved instances costs you on a monthly basis.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#normalized_units_to_purchaseString

The number of normalized units that Amazon Web Services recommends that you purchase.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_instances_to_purchaseString

The number of instances that Amazon Web Services recommends that you purchase.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#payment_optionString

The payment option for the commitment.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_instances_regionString

The Amazon Web Services Region of the commitment.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The service that you want your recommendations for.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#size_flex_eligibleBoolean

Determines whether the recommendation is size flexible.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#termString

The reserved instances recommendation term in years.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end

#upfront_costString

How much purchasing this instance costs you upfront.



1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/aws-sdk-costoptimizationhub/types.rb', line 1625

class RedshiftReservedInstancesConfiguration < Struct.new(
  :account_scope,
  :service,
  :normalized_units_to_purchase,
  :term,
  :payment_option,
  :number_of_instances_to_purchase,
  :instance_family,
  :instance_type,
  :reserved_instances_region,
  :size_flex_eligible,
  :current_generation,
  :upfront_cost,
  :monthly_recurring_cost)
  SENSITIVE = []
  include Aws::Structure
end